# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.17-v202403072232
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AgentStatusOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'remote_agent': 'bool',
        'remote_update_error': 'str',
        'remote_update_status': 'str',
        'status': 'str',
        'version': 'str'
    }

    attribute_map = {
        'name': 'name',
        'remote_agent': 'remoteAgent',
        'remote_update_error': 'remoteUpdateError',
        'remote_update_status': 'remoteUpdateStatus',
        'status': 'status',
        'version': 'version'
    }

    def __init__(self, name=None, remote_agent=False, remote_update_error=None, remote_update_status=None, status=None, version=None):
        """
        AgentStatusOutputV1 - a model defined in Swagger
        """

        self._name = None
        self._remote_agent = None
        self._remote_update_error = None
        self._remote_update_status = None
        self._status = None
        self._version = None

        if name is not None:
          self.name = name
        if remote_agent is not None:
          self.remote_agent = remote_agent
        if remote_update_error is not None:
          self.remote_update_error = remote_update_error
        if remote_update_status is not None:
          self.remote_update_status = remote_update_status
        if status is not None:
          self.status = status
        if version is not None:
          self.version = version

    @property
    def name(self):
        """
        Gets the name of this AgentStatusOutputV1.
        The name of the agent. This name uniquely identifies the agent

        :return: The name of this AgentStatusOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AgentStatusOutputV1.
        The name of the agent. This name uniquely identifies the agent

        :param name: The name of this AgentStatusOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def remote_agent(self):
        """
        Gets the remote_agent of this AgentStatusOutputV1.
        Indicates if the agent is a remote agent. This is false for local agents.

        :return: The remote_agent of this AgentStatusOutputV1.
        :rtype: bool
        """
        return self._remote_agent

    @remote_agent.setter
    def remote_agent(self, remote_agent):
        """
        Sets the remote_agent of this AgentStatusOutputV1.
        Indicates if the agent is a remote agent. This is false for local agents.

        :param remote_agent: The remote_agent of this AgentStatusOutputV1.
        :type: bool
        """

        self._remote_agent = remote_agent

    @property
    def remote_update_error(self):
        """
        Gets the remote_update_error of this AgentStatusOutputV1.
        Error if any for remote agent update

        :return: The remote_update_error of this AgentStatusOutputV1.
        :rtype: str
        """
        return self._remote_update_error

    @remote_update_error.setter
    def remote_update_error(self, remote_update_error):
        """
        Sets the remote_update_error of this AgentStatusOutputV1.
        Error if any for remote agent update

        :param remote_update_error: The remote_update_error of this AgentStatusOutputV1.
        :type: str
        """

        self._remote_update_error = remote_update_error

    @property
    def remote_update_status(self):
        """
        Gets the remote_update_status of this AgentStatusOutputV1.
        Version Update status of remote agents

        :return: The remote_update_status of this AgentStatusOutputV1.
        :rtype: str
        """
        return self._remote_update_status

    @remote_update_status.setter
    def remote_update_status(self, remote_update_status):
        """
        Sets the remote_update_status of this AgentStatusOutputV1.
        Version Update status of remote agents

        :param remote_update_status: The remote_update_status of this AgentStatusOutputV1.
        :type: str
        """

        self._remote_update_status = remote_update_status

    @property
    def status(self):
        """
        Gets the status of this AgentStatusOutputV1.
        The status of the current connection between the agent and the Seeq application server. Valid values are CONNECTED, CONNECTING and DISCONNECTED

        :return: The status of this AgentStatusOutputV1.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this AgentStatusOutputV1.
        The status of the current connection between the agent and the Seeq application server. Valid values are CONNECTED, CONNECTING and DISCONNECTED

        :param status: The status of this AgentStatusOutputV1.
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")

        self._status = status

    @property
    def version(self):
        """
        Gets the version of this AgentStatusOutputV1.
        The Seeq version of the agent

        :return: The version of this AgentStatusOutputV1.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this AgentStatusOutputV1.
        The Seeq version of the agent

        :param version: The version of this AgentStatusOutputV1.
        :type: str
        """

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AgentStatusOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.17-v202403072232
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ActivityOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'children_ids': 'list[str]',
        'description': 'str',
        'id': 'str',
        'properties': 'dict(str, str)'
    }

    attribute_map = {
        'category': 'category',
        'children_ids': 'childrenIds',
        'description': 'description',
        'id': 'id',
        'properties': 'properties'
    }

    def __init__(self, category=None, children_ids=None, description=None, id=None, properties=None):
        """
        ActivityOutputV1 - a model defined in Swagger
        """

        self._category = None
        self._children_ids = None
        self._description = None
        self._id = None
        self._properties = None

        if category is not None:
          self.category = category
        if children_ids is not None:
          self.children_ids = children_ids
        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if properties is not None:
          self.properties = properties

    @property
    def category(self):
        """
        Gets the category of this ActivityOutputV1.
        The kind of activity this represents, irrespective of specific instance parameters. Use this to do things like coloring activities of the same kind.

        :return: The category of this ActivityOutputV1.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this ActivityOutputV1.
        The kind of activity this represents, irrespective of specific instance parameters. Use this to do things like coloring activities of the same kind.

        :param category: The category of this ActivityOutputV1.
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")

        self._category = category

    @property
    def children_ids(self):
        """
        Gets the children_ids of this ActivityOutputV1.
        The (ephemeral) IDs of all children for this activity.

        :return: The children_ids of this ActivityOutputV1.
        :rtype: list[str]
        """
        return self._children_ids

    @children_ids.setter
    def children_ids(self, children_ids):
        """
        Sets the children_ids of this ActivityOutputV1.
        The (ephemeral) IDs of all children for this activity.

        :param children_ids: The children_ids of this ActivityOutputV1.
        :type: list[str]
        """
        if children_ids is None:
            raise ValueError("Invalid value for `children_ids`, must not be `None`")

        self._children_ids = children_ids

    @property
    def description(self):
        """
        Gets the description of this ActivityOutputV1.
        An admin-readable description of the operation being performed

        :return: The description of this ActivityOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ActivityOutputV1.
        An admin-readable description of the operation being performed

        :param description: The description of this ActivityOutputV1.
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this ActivityOutputV1.
        The (ephemeral) ID of the Activity. Only valid within the context of a particular snapshot, for example for correlating activities shared amongst multiple requests.

        :return: The id of this ActivityOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ActivityOutputV1.
        The (ephemeral) ID of the Activity. Only valid within the context of a particular snapshot, for example for correlating activities shared amongst multiple requests.

        :param id: The id of this ActivityOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def properties(self):
        """
        Gets the properties of this ActivityOutputV1.
        Additional details, such as the time interval, names, or identifiers

        :return: The properties of this ActivityOutputV1.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this ActivityOutputV1.
        Additional details, such as the time interval, names, or identifiers

        :param properties: The properties of this ActivityOutputV1.
        :type: dict(str, str)
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")

        self._properties = properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ActivityOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.17-v202403072232
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FoldedStackNodeV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children': 'list[FoldedStackNodeV1]',
        'interval_end': 'str',
        'interval_start': 'str',
        'name': 'str',
        'properties': 'dict(str, str)',
        'value': 'int'
    }

    attribute_map = {
        'children': 'children',
        'interval_end': 'intervalEnd',
        'interval_start': 'intervalStart',
        'name': 'name',
        'properties': 'properties',
        'value': 'value'
    }

    def __init__(self, children=None, interval_end=None, interval_start=None, name=None, properties=None, value=None):
        """
        FoldedStackNodeV1 - a model defined in Swagger
        """

        self._children = None
        self._interval_end = None
        self._interval_start = None
        self._name = None
        self._properties = None
        self._value = None

        if children is not None:
          self.children = children
        if interval_end is not None:
          self.interval_end = interval_end
        if interval_start is not None:
          self.interval_start = interval_start
        if name is not None:
          self.name = name
        if properties is not None:
          self.properties = properties
        if value is not None:
          self.value = value

    @property
    def children(self):
        """
        Gets the children of this FoldedStackNodeV1.

        :return: The children of this FoldedStackNodeV1.
        :rtype: list[FoldedStackNodeV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this FoldedStackNodeV1.

        :param children: The children of this FoldedStackNodeV1.
        :type: list[FoldedStackNodeV1]
        """

        self._children = children

    @property
    def interval_end(self):
        """
        Gets the interval_end of this FoldedStackNodeV1.

        :return: The interval_end of this FoldedStackNodeV1.
        :rtype: str
        """
        return self._interval_end

    @interval_end.setter
    def interval_end(self, interval_end):
        """
        Sets the interval_end of this FoldedStackNodeV1.

        :param interval_end: The interval_end of this FoldedStackNodeV1.
        :type: str
        """

        self._interval_end = interval_end

    @property
    def interval_start(self):
        """
        Gets the interval_start of this FoldedStackNodeV1.

        :return: The interval_start of this FoldedStackNodeV1.
        :rtype: str
        """
        return self._interval_start

    @interval_start.setter
    def interval_start(self, interval_start):
        """
        Sets the interval_start of this FoldedStackNodeV1.

        :param interval_start: The interval_start of this FoldedStackNodeV1.
        :type: str
        """

        self._interval_start = interval_start

    @property
    def name(self):
        """
        Gets the name of this FoldedStackNodeV1.

        :return: The name of this FoldedStackNodeV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FoldedStackNodeV1.

        :param name: The name of this FoldedStackNodeV1.
        :type: str
        """

        self._name = name

    @property
    def properties(self):
        """
        Gets the properties of this FoldedStackNodeV1.

        :return: The properties of this FoldedStackNodeV1.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this FoldedStackNodeV1.

        :param properties: The properties of this FoldedStackNodeV1.
        :type: dict(str, str)
        """

        self._properties = properties

    @property
    def value(self):
        """
        Gets the value of this FoldedStackNodeV1.

        :return: The value of this FoldedStackNodeV1.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this FoldedStackNodeV1.

        :param value: The value of this FoldedStackNodeV1.
        :type: int
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FoldedStackNodeV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.17-v202403072232
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ReportTemplateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'folder_id': 'str',
        'html_template': 'str',
        'name': 'str'
    }

    attribute_map = {
        'description': 'description',
        'folder_id': 'folderId',
        'html_template': 'htmlTemplate',
        'name': 'name'
    }

    def __init__(self, description=None, folder_id=None, html_template=None, name=None):
        """
        ReportTemplateInputV1 - a model defined in Swagger
        """

        self._description = None
        self._folder_id = None
        self._html_template = None
        self._name = None

        if description is not None:
          self.description = description
        if folder_id is not None:
          self.folder_id = folder_id
        if html_template is not None:
          self.html_template = html_template
        if name is not None:
          self.name = name

    @property
    def description(self):
        """
        Gets the description of this ReportTemplateInputV1.
        The description of the template

        :return: The description of this ReportTemplateInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportTemplateInputV1.
        The description of the template

        :param description: The description of this ReportTemplateInputV1.
        :type: str
        """

        self._description = description

    @property
    def folder_id(self):
        """
        Gets the folder_id of this ReportTemplateInputV1.
        The id of the folder to place the new report template into. Special values of 'mine' or 'corporate' to place the item in the authenticated user's home folder or the corporate folder, respectively. If null, the workbook will be created in the authenticated user's home folder.

        :return: The folder_id of this ReportTemplateInputV1.
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """
        Sets the folder_id of this ReportTemplateInputV1.
        The id of the folder to place the new report template into. Special values of 'mine' or 'corporate' to place the item in the authenticated user's home folder or the corporate folder, respectively. If null, the workbook will be created in the authenticated user's home folder.

        :param folder_id: The folder_id of this ReportTemplateInputV1.
        :type: str
        """

        self._folder_id = folder_id

    @property
    def html_template(self):
        """
        Gets the html_template of this ReportTemplateInputV1.
        The actual html template for the report template

        :return: The html_template of this ReportTemplateInputV1.
        :rtype: str
        """
        return self._html_template

    @html_template.setter
    def html_template(self, html_template):
        """
        Sets the html_template of this ReportTemplateInputV1.
        The actual html template for the report template

        :param html_template: The html_template of this ReportTemplateInputV1.
        :type: str
        """
        if html_template is None:
            raise ValueError("Invalid value for `html_template`, must not be `None`")

        self._html_template = html_template

    @property
    def name(self):
        """
        Gets the name of this ReportTemplateInputV1.
        The name of the template

        :return: The name of this ReportTemplateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReportTemplateInputV1.
        The name of the template

        :param name: The name of this ReportTemplateInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportTemplateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.17-v202403072232
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PriorityV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'color': 'str',
        'level': 'int',
        'name': 'str'
    }

    attribute_map = {
        'color': 'color',
        'level': 'level',
        'name': 'name'
    }

    def __init__(self, color=None, level=None, name=None):
        """
        PriorityV1 - a model defined in Swagger
        """

        self._color = None
        self._level = None
        self._name = None

        if color is not None:
          self.color = color
        if level is not None:
          self.level = level
        if name is not None:
          self.name = name

    @property
    def color(self):
        """
        Gets the color of this PriorityV1.
        A hex code (including pound sign) representing the color assigned to this priority

        :return: The color of this PriorityV1.
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this PriorityV1.
        A hex code (including pound sign) representing the color assigned to this priority

        :param color: The color of this PriorityV1.
        :type: str
        """
        if color is None:
            raise ValueError("Invalid value for `color`, must not be `None`")

        self._color = color

    @property
    def level(self):
        """
        Gets the level of this PriorityV1.
        An integer representing the priority level. 0 is used for neutral, positive numbers are used for high thresholds and negative numbers for low thresholds

        :return: The level of this PriorityV1.
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this PriorityV1.
        An integer representing the priority level. 0 is used for neutral, positive numbers are used for high thresholds and negative numbers for low thresholds

        :param level: The level of this PriorityV1.
        :type: int
        """
        if level is None:
            raise ValueError("Invalid value for `level`, must not be `None`")

        self._level = level

    @property
    def name(self):
        """
        Gets the name of this PriorityV1.
        The name of this priority

        :return: The name of this PriorityV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PriorityV1.
        The name of this priority

        :param name: The name of this PriorityV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PriorityV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
